@@ -2,23 +2,25 @@ package App::bif::list::hubs;
 use strict;
 use warnings;
 use App::bif::Context;
+use Term::ANSIColor qw/color/;
 
-our $VERSION = '0.1.0_25';
+our $VERSION = '0.1.0_26';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
     my $db  = $ctx->db;
 
-    DBIx::ThinSQL->import(qw/ count /);
+    DBIx::ThinSQL->import(qw/ count qv/);
 
     my $data = $db->xarrays(
         select => [
-            'h.id',        'COALESCE(h.name,"") AS hname',
+            qv( color('dark') . 'hub' . color('reset') )->as('type'),
+            'COALESCE(h.name,"") AS hname',
             'hr.location', 'COUNT(p.id)',
         ],
         from       => 'hubs h',
         inner_join => 'hub_repos hr',
-        on         => 'hr.id = h.default_repo_id AND h.local IS NULL',
+        on         => 'hr.id = h.default_repo_id',
         left_join  => 'projects p',
         on         => 'p.hub_id = h.id',
         group_by   => [ 'h.id', 'hname', 'hr.location' ],
@@ -29,8 +31,8 @@ sub run {
 
     $ctx->start_pager( scalar @$data );
 
-    print $ctx->render_table( ' r  l  l  r ',
-        [ 'ID', 'Name', 'Location', 'Projects' ], $data );
+    print $ctx->render_table( ' l l  l  r ',
+        [ 'Type', 'Name', 'Location', 'Projects' ], $data );
 
     $ctx->end_pager;
 
@@ -46,7 +48,7 @@ bif-list-hubs - list hubs registered with current repository
 
 =head1 VERSION
 
-0.1.0_25 (2014-06-14)
+0.1.0_26 (2014-07-23)
 
 =head1 SYNOPSIS
 
