@@ -16,26 +16,26 @@ FOR EACH ROW
 BEGIN
     SELECT debug(
         OLD.id,
-        OLD.status_id
+        OLD.update_id,
+        OLD.status_id,
+        OLD.title
     );
 
+    DELETE FROM
+        topics
+    WHERE
+        id = OLD.id
+    ;
+
+    /*
+        The following is necessary, because although FK relationships
+        do result in the remove of rows from tasks_tomerge, the
+        deletion of rows from task_deltas just inserts more rows.
+    */
     DELETE FROM
         tasks_tomerge
     WHERE
         task_id = OLD.id
     ;
 
-    DELETE FROM
-        updates
-    WHERE
-        id = (
-            SELECT
-                first_update_id
-            FROM
-                topics
-            WHERE
-                id = OLD.id
-        )
-    ;
-
 END;
